@@ -1,5 +1,5 @@
 # __init__.py -- Contrib module for Dulwich
-# Copyright (C) 2014 Jelmer Vernooij <jelmer@samba.org>
+# Copyright (C) 2014 Jelmer Vernooij <jelmer@jelmer.uk>
 #
 # Dulwich is dual-licensed under the Apache License, Version 2.0 and the GNU
 # General Public License as public by the Free Software Foundation; version 2.0
@@ -21,9 +21,11 @@
 
 def test_suite():
     import unittest
+
     names = [
-        'swift',
-        ]
-    module_names = ['dulwich.contrib.test_' + name for name in names]
+        "release_robot",
+        "swift",
+    ]
+    module_names = ["dulwich.contrib.test_" + name for name in names]
     loader = unittest.TestLoader()
     return loader.loadTestsFromNames(module_names)
